<?php

if (!defined('ABSPATH'))
    exit; // Exit if accessed directly

/**
 * WC_Settings_Bonus_Products.
 */
if (!class_exists('WOOBP_Settings')) {

    class WOOBP_Settings extends WC_Settings_Page {

        /**
         * Constructor.
         */
        public function __construct() {

            $this->id = 'woobp_settings';
            $this->label = __('Bonus Product', WOO_BONUS_PRODUCT_DOMAIN);

            add_filter('woocommerce_settings_tabs_array', array($this, 'add_settings_page'), 30); // 30 so it is after the emails tab
            add_action('woocommerce_settings_' . $this->id, array($this, 'output'));
            add_action('woocommerce_settings_save_' . $this->id, array($this, 'save'));
            add_action('woocommerce_sections_' . $this->id, array($this, 'output_sections'));

            add_action('woocommerce_admin_field_woobp_button', array($this, 'render_woobp_button'));
            add_action('woocommerce_admin_field_woobp_editor', array($this, 'render_woobp_editor'));
            add_action('woocommerce_admin_field_woobp_help_resources', array($this, 'render_woobp_help_resources'));
            add_action('woocommerce_admin_field_woobp_help_resources', array($this, 'render_woobp_help_resources'));
            add_action('woocommerce_admin_field_woobp_image_dimension', array($this, 'render_woobp_image_dimension'));
        }

        /**
         * Get sections.
         *
         * @return array
         * @since 1.0.0
         */
        public function get_sections() {

            $sections = array(
                ''              => __('General', WOO_BONUS_PRODUCT_DOMAIN),
                'woobp_filters' => __('Filters', WOO_BONUS_PRODUCT_DOMAIN),
                'woobp_permissions' => __('Permissions', WOO_BONUS_PRODUCT_DOMAIN),
            );

            return apply_filters('woocommerce_get_sections_' . $this->id, $sections);
        }

        /**
         * Output the settings.
         *
         * @since 1.0.0
         */
        public function output() {

            global $current_section;

            $settings = $this->get_settings($current_section);
            WC_Admin_Settings::output_fields($settings);
        }

        /**
         * Save settings.
         *
         * @since 1.0.0
         */
        public function save() {

            global $current_section;

            $settings = $this->get_settings($current_section);

            // Filter wysiwyg content so it gets stored properly after sanitization
            if (isset($_POST['noaccess_message']) && !empty($_POST['noaccess_message'])) {

                foreach ($_POST['noaccess_message'] as $index => $content) {

                    $_POST[$index] = htmlentities(wpautop($content));
                }
            }

            WC_Admin_Settings::save_fields($settings);
        }

        /**
         * Get settings array.
         *
         * @param string $current_section
         *
         * @return mixed
         * @since 1.0.0
         */
        public function get_settings($current_section = '') {

            if ($current_section == 'woobp_filters') {

                // Filters Section
                $settings = apply_filters('woobp_filters_settings', $this->_get_filters_section_settings());
            } elseif ($current_section == 'woobp_permissions') {

                // Permissions Section
                $settings = apply_filters('woobp_permissions_settings', $this->_get_permissions_section_settings());
            } else {

                // General Settings
                $settings = apply_filters('woobp_general_settings', $this->_get_general_section_settings());
            }

            return apply_filters('woocommerce_get_settings_' . $this->id, $settings, $current_section);
        }

        /*
          * |--------------------------------------------------------------------------------------------------------------
          * | Section Settings
          * |--------------------------------------------------------------------------------------------------------------
         */

        /**
         * Get general section settings.
         *
         * @since 1.0.0
         * @since 1.3.0 Add option to show/hide quantity based discounts on wholesale order page.
         *
         * @return array
         */
        private function _get_general_section_settings() {

            $limit_option = Array(
                'cartvalue'     => __('Minimum Product items in cart', WOO_BONUS_PRODUCT_DOMAIN),
                'cartamount'    => __('Minimum Amount in cart', WOO_BONUS_PRODUCT_DOMAIN),
            );
            return array(
                array(
                    'title'     => __('General Options', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'title',
                    'desc'      => '',
                    'id'        => 'woobp_general_main_title'
                ),
                array(
                    'title'     => __('Allow Bonus Product?', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'checkbox',
                    'desc'      => __('Enable Bonus Product', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_allow',
                    'default'   => 'yes',
                    'desc_tip'  => __('If it is checked bonus product is applicable on front side', WOO_BONUS_PRODUCT_DOMAIN),
                ),
                array(
                    'title'     => __('Bonus Product limited to', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'select',
                    'options'   => $limit_option,
                    'id'        => 'woo_bonus_product_limited_to',
                    'default'   => 'yes',
                    'desc_tip'  => __('Select category for bonus product', WOO_BONUS_PRODUCT_DOMAIN),
                ),
                array(
                    'title'             => __('Select Min. Product Items', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'              => 'number',
                    'desc_tip'          => __('Bonus Product drop down will display only if no of product in cart is greater then min product.', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'                => 'woo_bonus_product_min_cart',
                    'custom_attributes' => array(
                        'min'   => 0,
                        'step'  => 1,
                    ),
                ),
                array(
                    'type'      => 'sectionend',
                    'id'        => 'woobp_general_options_sectionend'
                ),
                array(
                    'title'     => __('Bonus Label Options', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'title',
                    'desc'      => __('This settings apply on single product page.', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_label_section_title'
                ),
                array(
                    'title'     => __('Bonus Label Text', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'text',
                    'desc_tip'  => __('Text for bonus product on single product page.', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_label',
                    'default'   => __('Bonus Product included!', WOO_BONUS_PRODUCT_DOMAIN),
                ),
                array(
                    'title'     => __('Select Label Color', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'text',
                    'class'     => 'wbp-color-picker',
                    'desc_tip'  => __('Add color #code value here for bonus label.Example: #808800', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woobp_general_label_color',
                    'default'   => '#96588a',
                ), array(
                    'type'      => 'sectionend',
                    'id'        => 'woobp_general_sectionend'
                )
            );
        }

        /**
         * Get filters section settings.
         *
         * @return array
         * @since 1.0.0
         */
        private function _get_filters_section_settings() {

            $woo_bonus_product_category_products = get_option('woo_bonus_product_category_products',true);
            $cat_products = array();
            if(is_array($woo_bonus_product_category_products)){
                foreach($woo_bonus_product_category_products as $product_id){
                    $cat_products[$product_id] = get_the_title($product_id);
                }
            }

            $woo_bonus_product_id = get_option('woo_bonus_product_id');
            $woo_bonus_product_category = get_option('woo_bonus_product_category');
            
            if (isset($woo_bonus_product_category)) {
                $woo_bonus_category = $woo_bonus_product_category;
            } else {
                $woo_bonus_category = array();
            }

            if(!empty($woo_bonus_category)){
                $args_product['post_type'] = "product";
                $args_product['tax_query']['relation'] = 'or';
                foreach ($woo_bonus_category as $category) {
                    $args_product['tax_query'][] = array(
                        'taxonomy' => 'product_cat',
                        'field' => 'term_id',
                        'terms' => $category,
                    );
                }
                $products_post = new WP_Query($args_product);
                if(!empty($products_post)){
                    while($products_post->have_posts()) : $products_post->the_post();
                        $cat_products[get_the_ID()] = get_the_title();
                    endwhile;
                } else {
                    $products = array();
                }
            }
            $category_products = array_unique ($cat_products);

            if (isset($woo_bonus_product_id)) {
                $woo_bonus_products = $woo_bonus_product_id;
            } else {
                $woo_bonus_products = array();
            }

            $product_categories = get_terms('product_cat');
            if (!empty($product_categories)) {
                foreach ($product_categories as $key => $category) {
                    $categories[$category->term_id] = $category->name;
                }
            }
            $taxonomy = 'product_cat';
            $orderby = 'name';
            $show_count = 0;      // 1 for yes, 0 for no
            $pad_counts = 0;      // 1 for yes, 0 for no
            $hierarchical = 1;      // 1 for yes, 0 for no
            $title = '';
            $empty = 0;

            $args = array(
                'taxonomy' => $taxonomy,
                'orderby' => $orderby,
                'show_count' => $show_count,
                'pad_counts' => $pad_counts,
                'hierarchical' => $hierarchical,
                'title_li' => $title,
                'hide_empty' => $empty
            );
            $all_categories = get_categories($args);
            foreach ($all_categories as $cat) {
                $categories[$cat->term_id] = $cat->name;
            }

            $products_array[0] = __("---Select Products---", WOO_BONUS_PRODUCT_DOMAIN);

            $all_products_args['post_type'] = "product";
            $all_products_args['posts_per_page'] = -1 ;
            $all_products = new WP_Query($all_products_args);

            while($all_products->have_posts()) : $all_products->the_post();
                $products_array[get_the_ID()] = get_the_title();

            endwhile;

            if(empty($cat_products)){
                $cat_products = array();
            }

            $bonus_type = array(
                'all'       => __('All Products', WOO_BONUS_PRODUCT_DOMAIN),
                'specific'  => __('Specific Product', WOO_BONUS_PRODUCT_DOMAIN),
            );
            $settings = array(
                'section_title' => array(
                    'name'  => __('Category Filters', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'woo_bonus_product_filters_main_title'
                ),
                'bonus_category' => array(
                    'name'      => __('Select Category', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'multiselect',
                    'options'   => $categories,
                    'class'     => 'wc-enhanced-select-nostd',
                    'css'       => 'min-width:300px;',
                    'desc'      => __('Select category for bonus product', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_category',
                    'desc_tip'  => true,
                ),
                'bonus_category_product' => array(
                    'name'      => __('Select Products from Categories', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'multiselect',
                    'options'   => $category_products,
                    'class'     => 'wc-enhanced-select-nostd',
                    'css'       => 'min-width:300px;',
                    'desc'      => __('Select Products for bonus product', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_category_products',
                    'desc_tip'  => true,
                ),
                'bonus_category_type' => array(
                    'name'      => __('Bonus Type', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'select',
                    'options'   => $bonus_type,
                    'class'     => 'wc-enhanced-select-nostd',
                    'css'       => 'min-width:300px;',
                    'desc'      => __('Select Bonus type for products.', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_category_type',
                    'desc_tip'  => true,
                ),
                'bonus_category_specific' => array(
                    'name'      => __('Select Specific Product', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'select',
                    'options'   => $products_array,
                    'class'     => 'wc-enhanced-select-nostd',
                    'css'       => 'min-width:300px;',
                    'desc'      => __('<span class="description-span"><span>Note: </span>If you will choose bonus type as specific product then that product will not show bonus product label at front-end.</span>', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_category_specific',
                    'desc_tip'  => sprintf( __('<span>Note: </span>If you will choose bonus type as specific product then that product will not show bonus product label at front-end.', WOO_BONUS_PRODUCT_DOMAIN )),
                ),
                array(
                    'type'  => 'sectionend',
                    'id'    => 'woo_bonus_product_filters_end_title',
                ),
                'title' => array(
                    'name'  => __('Product Filters', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'woo_bonus_product_filters_main_title'
                ),
                'title' => array(
                    'name'  => __('Select Product', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'  => 'title',
                    'desc'  => '',
                    'id'    => 'woo_bonus_product_filters_title'
                ),
                'bonus_product' => array(
                    'name'      => __('Select Products', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'multiselect',
                    'options'   => $products_array,
                    'class'     => 'wc-enhanced-select-nostd',
                    'css'       => 'min-width:300px;',
                    'desc'      => __('Select product allow as bonus product.', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_id',
                    'desc_tip'  => true,
                ),
                'bonus_product_type' => array(
                    'name'      => __('Bonus Type', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'select',
                    'options'   => $bonus_type,
                    'class'     => 'wc-enhanced-select-nostd',
                    'css'       => 'min-width:300px;',
                    'desc'      => __('Select Bonus type for products.', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_type',
                    'desc_tip'  => true,
                ),
                'bonus_product_specific' => array(
                    'name'      => __('Select Specific Product', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'select',
                    'options'   => $products_array,
                    'class'     => 'wc-enhanced-select-nostd',
                    'css'       => 'min-width:300px;',
                    'desc'      => __('<span class="description-span"><span>Note: </span>If you will choose bonus type as specific product then that product will not show bonus product label at front-end.</span>', WOO_BONUS_PRODUCT_DOMAIN),
                    'id'        => 'woo_bonus_product_specific',
                    'desc_tip'  => false,
                ),
                'section_end' => array(
                    'type'  => 'sectionend',
                    'id'    => 'woo_bonus_product_filters_end_title'
                )
            );
            return $settings;
        }

        /**
         * Get permissions section settings.
         *
         * @return array
         * @since 1.0.0
         */
        private function _get_permissions_section_settings() {

            // Get all user roles
            global $wp_roles;

            if (!isset($wp_roles))
                $wp_roles = new WP_Roles();

            $allUserRoles = $wp_roles->get_names();

            return array(
                array(
                    'title'     => __('Permissions Options', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'      => 'title',
                    'desc'      => '',
                    'id'        => 'woobp_permissions_main_title'
                ),
                array(
                    'title'             => __('User Role Filter', WOO_BONUS_PRODUCT_DOMAIN),
                    'type'              => 'multiselect',
                    'desc'              => __('Only allow a given user role/s to access the wholesale page. Left blank to disable filter.', WOO_BONUS_PRODUCT_DOMAIN),
                    'desc_tip'          => true,
                    'id'                => 'woobp_permissions_user_role_filter',
                    'class'             => 'chosen_select',
                    'css'               => 'min-width:300px;',
                    'custom_attributes' => array(
                        'multiple'          => 'multiple',
                        'data-placeholder'  => __('Select Some User Roles...', WOO_BONUS_PRODUCT_DOMAIN)
                    ),
                    'options' => $allUserRoles
                ),
                array(
                    'type'  => 'sectionend',
                    'id'    => 'woobp_permissions_sectionend'
                )
            );
        }

    }

}

return new WOOBP_Settings();
