<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to woo-bonus-product/template/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.8.0
 */

defined( 'ABSPATH' ) || exit;

wc_print_notices();

do_action( 'woocommerce_before_cart' ); ?>

<form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
	<?php do_action( 'woocommerce_before_cart_table' ); ?>

	<table class="shop_table shop_table_responsive cart woocommerce-cart-form__contents" cellspacing="0">
		<thead>
			<tr>
				<th class="product-remove">&nbsp;</th>
				<th class="product-name"><?php esc_html_e( 'Product', WOO_BONUS_PRODUCT_DOMAIN ); ?></th>
				<th class="product-thumbnail"><?php esc_html_e('Bonus Product', WOO_BONUS_PRODUCT_DOMAIN); ?></th>
				<th class="product-price"><?php esc_html_e( 'Price', WOO_BONUS_PRODUCT_DOMAIN ); ?></th>
				<th class="product-quantity"><?php esc_html_e( 'Quantity', WOO_BONUS_PRODUCT_DOMAIN ); ?></th>
				<th class="product-subtotal"><?php esc_html_e( 'Total ', WOO_BONUS_PRODUCT_DOMAIN ); ?></th>
			</tr>
		</thead>
		<tbody>
			<?php do_action( 'woocommerce_before_cart_contents' ); ?>
			<?php
			foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
				$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
				$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );
				if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
					$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
					?>
					<tr class="woocommerce-cart-form__cart-item <?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">
                    <td class="product-remove">
                            <?php
                            // @codingStandardsIgnoreLine
                            echo apply_filters('woocommerce_cart_item_remove_link', sprintf(
                                            '<a href="%s" class="remove" aria-label="%s" data-product_id="%s" data-product_sku="%s">&times;</a>', esc_url(wc_get_cart_remove_url($cart_item_key)), __('Remove this item', WOO_BONUS_PRODUCT_DOMAIN), esc_attr($product_id), esc_attr($_product->get_sku())
                                    ), $cart_item_key);
                            ?>
                    </td>
                    <td class="product-name" data-title="<?php esc_attr_e('Product', WOO_BONUS_PRODUCT_DOMAIN); ?>">
                        <?php
                        if (!$product_permalink) {
                            echo wp_kses_post(apply_filters('woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key) . '&nbsp;');
                        } else {
                            echo wp_kses_post(apply_filters('woocommerce_cart_item_name', sprintf('<a href="%s">%s</a>', esc_url($product_permalink), $_product->get_name()), $cart_item, $cart_item_key));
                        }
                        do_action('woocommerce_after_cart_item_name', $cart_item, $cart_item_key);
                        // Backorder notification.
                        if ($_product->backorders_require_notification() && $_product->is_on_backorder($cart_item['quantity'])) {
                            echo wp_kses_post(apply_filters('woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__('Available on backorder', WOO_BONUS_PRODUCT_DOMAIN) . '</p>'));
                        }
                        ?>
                    </td>
                    <td class="woo-bonus-product" data-title="<?php echo $product_id; ?>">
                        <?php
                        $bonus_product_array = array();
                        $user_id = get_current_user_id();
                        $woo_bonus_product_to_cart = get_post_meta($product_id, "woo_bonus_product_to_cart_" . $user_id, true);
                        $product_array = array();

                        //category filters
                        $woo_bonus_filter_category = get_option('woo_bonus_product_category');
                        $woo_bonus_filter_category_products = get_option('woo_bonus_product_category_products');
                        $woo_bonus_filter_category_type = get_option('woo_bonus_category_type');
                        $woo_bonus_filter_category_specific = get_option('woo_bonus_category_specific');

                        $woo_bonus_product_single_products = get_post_meta($product_id, 'woo_bonus_product_single_products', true);

                        //product filters
                        $woo_bonus_filter_product_type = get_option('woo_bonus_product_type');
                        $woo_bonus_filter_product_specific = get_option('woo_bonus_product_specific');

                        $woo_bonus_filter_product_id = get_option('woo_bonus_product_id');
                        $args_product['post__in'] = $woo_bonus_filter_product_id;
                        $args_product['post_type'] = "product";
                        $products_by_product = new WP_Query($args_product);

                        // if category filters are not empty
                        if (!empty($woo_bonus_filter_category)) {
                            if ($woo_bonus_filter_category_type == "specific") {
                                if ($woo_bonus_filter_category_specific != $product_id) {
                                    $bonus_product_array[$woo_bonus_filter_category_specific] = get_the_title($woo_bonus_filter_category_specific);
                                }
                            } else {
                                $args['post_type'] = "product";
                                $args['tax_query']['relation'] = 'or';
                                foreach ($woo_bonus_filter_category as $category) {
                                    $args['tax_query'][] = array(
                                        'taxonomy' => 'product_cat',
                                        'field' => 'term_id',
                                        'terms' => $woo_bonus_filter_category,
                                    );
                                }
                                $args['post__not_in'] = array($product_id);
                                $products_category = new WP_Query($args);
                                if (!empty($products_category)) {
                                    while ($products_category->have_posts()) : $products_category->the_post();
                                        if (get_the_ID() != $product_id) {
                                            $bonus_product_array[get_the_ID()] = get_the_title();
                                        }
                                    endwhile;
                                }
                            }
                        }// closed !empty category
                        
                        // if product filters are not empty
                        if (!empty($woo_bonus_filter_product_id)) {
                            if ($woo_bonus_filter_product_type == "specific") {
                                if (get_option("woo_bonus_product_specific") != $product_id) {
                                    $bonus_product_array[get_option("woo_bonus_product_specific")] = get_the_title(get_option("woo_bonus_product_specific"));
                                }
                            } else {
                                if (!empty($woo_bonus_filter_product_id)) {
                                    while ($products_by_product->have_posts()) : $products_by_product->the_post();
                                        if (get_the_ID() != $product_id) {
                                            $bonus_product_array[get_the_ID()] = get_the_title();
                                        }
                                    endwhile;
                                }
                            }
                        }// closed !empty product
                        if (empty(wc_get_formatted_cart_item_data($cart_item))) {
                            if (is_array($woo_bonus_product_single_products) && !empty($woo_bonus_product_single_products)) {
                                $args_single_product['post_type'] = "product";
                                $args_single_product['post__in'] = $woo_bonus_product_single_products;
                                $single_products = new WP_Query($args_single_product);
                                $user_id = get_current_user_id();
                                $woo_bonus_products = get_post_meta($product_id, "woo_bonus_product_to_cart_" . $user_id, true);
                                ?>
                                <div class="select-cover">
                                    <select name="bonus_product_id[]" id="bonus_product_id">
                                        <option value="0"><?php esc_html_e('-- Select Bonus Product --', WOO_BONUS_PRODUCT_DOMAIN); ?></option>
                                        <?php
                                        while ($single_products->have_posts()) : $single_products->the_post();
                                            ?>
                                            <option value="<?php echo get_the_ID(); ?>" <?php echo (get_the_ID() == $woo_bonus_products) ? 'selected="selected"' : ''; ?> ><?php echo get_the_title(); ?></option>
                                            <?php
                                        endwhile;
                                        ?>
                                    </select>
                                </div>
                                <a href="#" id="woo_bonus_add_product_to_cart_<?php echo $product_id; ?>"><?php _e("Add Bonus Product", WOO_BONUS_PRODUCT_DOMAIN); ?></a>
                                <?php
                            } else {
                                if (!empty($bonus_product_array)) {
                                    ?>
                                    <div class="select-cover">
                                        <select name="bonus_product_id[]" id="bonus_product_id">
                                            <option value="0"><?php esc_html_e('-- Select Bonus Product --', WOO_BONUS_PRODUCT_DOMAIN); ?></option>
                                            <?php foreach ($bonus_product_array as $id => $name) { ?>
                                                <option value="<?php echo $id; ?>" <?php echo ($woo_bonus_product_to_cart == $id) ? "selected=selected" : ""; ?>><?php echo $name; ?></option>
                                                <?php
                                            }
                                            ?>
                                        </select>
                                    </div>
                                    <a href="#" id="woo_bonus_add_product_to_cart_<?php echo $product_id; ?>"><?php _e("Add Bonus Product", WOO_BONUS_PRODUCT_DOMAIN); ?></a>
                                    <?php
                                } else {
                                    ?>
                                    <span><?php _e("No Bonus product", WOO_BONUS_PRODUCT_DOMAIN); ?></span>
                                    <?php
                                }
                            }
                        } else {
                            // Meta data.
                            echo wc_get_formatted_cart_item_data($cart_item); // PHPCS: XSS ok.
                        }
                        ?>
                    </td>
                    <td class="product-name" data-title="<?php esc_attr_e( 'Product', WOO_BONUS_PRODUCT_DOMAIN ); ?>">
                        <?php
                        if ( ! $product_permalink ) {
                            echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;' );
                        } else {
                            echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ) );
                        }
                        do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );
                        // Meta data.
                        echo wc_get_formatted_cart_item_data( $cart_item ); // PHPCS: XSS ok.
                        // Backorder notification.
                        if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
                            echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', WOO_BONUS_PRODUCT_DOMAIN ) . '</p>', $product_id ) );
                        }
                        ?>
                    </td>
                    <td class="product-price" data-title="<?php esc_attr_e('Price', WOO_BONUS_PRODUCT_DOMAIN); ?>">
                        <?php echo apply_filters('woocommerce_cart_item_price', WC()->cart->get_product_price($_product), $cart_item, $cart_item_key); // PHPCS: XSS ok.  ?>
                    </td>
                    <td class="product-quantity" data-title="<?php esc_attr_e('Quantity', WOO_BONUS_PRODUCT_DOMAIN); ?>">
                        <?php
                        if ($_product->is_sold_individually()) {
                            $product_quantity = sprintf('1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key);
                        } else {
                            $product_quantity = woocommerce_quantity_input(array(
                                'input_name' => "cart[{$cart_item_key}][qty]",
                                'input_value' => $cart_item['quantity'],
                                'max_value' => $_product->get_max_purchase_quantity(),
                                'min_value' => '0',
                                'product_name' => $_product->get_name(),
                                    ), $_product, false);
                        }

                        echo apply_filters('woocommerce_cart_item_quantity', $product_quantity, $cart_item_key, $cart_item); // PHPCS: XSS ok.
                        ?>
                    </td>
                    <td class="product-subtotal" data-title="<?php esc_attr_e('Total', WOO_BONUS_PRODUCT_DOMAIN); ?>">
                        <?php echo apply_filters('woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal($_product, $cart_item['quantity']), $cart_item, $cart_item_key); // PHPCS: XSS ok.  ?>
                    </td>
					</tr>
					<?php
				}
			}
			?>
			<?php do_action( 'woocommerce_cart_contents' ); ?>
			<tr>
				<td colspan="6" class="actions">
					<?php if ( wc_coupons_enabled() ) { ?>
						<div class="coupon">
							<label for="coupon_code"><?php esc_html_e( 'Coupon:', WOO_BONUS_PRODUCT_DOMAIN ); ?></label>
							<input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', WOO_BONUS_PRODUCT_DOMAIN ); ?>" /> 
							<button type="submit" class="button" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', WOO_BONUS_PRODUCT_DOMAIN ); ?>"><?php esc_attr_e( 'Apply coupon', WOO_BONUS_PRODUCT_DOMAIN ); ?></button>
							<?php do_action( 'woocommerce_cart_coupon' ); ?>
						</div>
					<?php } ?>
					<button type="submit" class="button" name="update_cart" value="<?php esc_attr_e( 'Update cart', WOO_BONUS_PRODUCT_DOMAIN ); ?>"><?php esc_html_e( 'Update cart', WOO_BONUS_PRODUCT_DOMAIN ); ?></button>

					<?php do_action( 'woocommerce_cart_actions' ); ?>

					<?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
				</td>
			</tr>
			<?php do_action( 'woocommerce_after_cart_contents' ); ?>
		</tbody>
	</table>
	<?php do_action( 'woocommerce_after_cart_table' ); ?>
</form>

<div class="cart-collaterals">
	<?php
		/**
		 * Cart collaterals hook.
		 *
		 * @hooked woocommerce_cross_sell_display
		 * @hooked woocommerce_cart_totals - 10
		 */
		do_action( 'woocommerce_cart_collaterals' );
	?>
</div>

<?php do_action( 'woocommerce_after_cart' ); ?>
