<?php
/**
 * Plugin Name: Bonus Product for WooCommerce
 * Plugin URI: https://www.techeshta.com/product/bonus-product-for-woocommerce/
 * Description: It offers you to add new Bonus Product with any product - based on category, single product or whole shop.
 * Version: 1.2
 * Author: 20script
 * Author URI: https://www.20script.ir
 * Stable tag: 1.2
 * Requires at least: 4.0
 * Tested up to: 6.3.1
 * WC tested up to: 7.6

 * Text Domain: woo-bonus-product
 */
/**
 * Exit if accessed directly
 */
if (!defined('ABSPATH')) {
    exit;
}

define('WOO_BONUS_PRODUCT_PLUGIN_URL', plugin_dir_url(__FILE__));
define('WOO_BONUS_PRODUCT_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('WOO_BONUS_PRODUCT_DOMAIN', 'woo-bonus-product');

add_filter('woocommerce_locate_template', 'woo_bonus_addon_plugin_template', 1, 3);
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'woo_bonus_action_links');
add_filter('woocommerce_get_settings_pages', 'woo_bonus_plugin_settings');

add_action('init', 'woo_bonus_init_localization');
add_action('wp_enqueue_scripts', 'woo_bonus_enqueue_scripts');
add_action('admin_enqueue_scripts', 'woo_bonus_enqueue_admin_scripts');

add_action('woocommerce_before_add_to_cart_form', 'woo_bonus_product_label');
add_action('wp_ajax_add_bonus_product_ajax', 'woo_bonus_add_product_to_cart', 20, 1);
add_action('wp_ajax_get_bonus_category_product', 'woo_bonus_get_category_products');

add_action('woocommerce_product_write_panel_tabs', 'woo_bonus_create_admin_product_tab');
add_action('woocommerce_product_data_panels', 'woo_bonus_tab_contents');
add_action('woocommerce_process_product_meta', 'woo_bonus_process_tab');

/**
 * Load the plugin text-domain
 * 
 * @access public
 * @since  1.0.1
 */
if (!function_exists('woo_bonus_init_localization')) {
    
    function woo_bonus_init_localization() {
        load_plugin_textdomain(WOO_BONUS_PRODUCT_DOMAIN, false, basename(dirname(__FILE__)) . '/languages');
    }
    
}

/**
 * Register and enqueue admin js
 * 
 * @access public
 * @since  1.0.0
 */
if (!function_exists('woo_bonus_enqueue_admin_scripts')) {

    function woo_bonus_enqueue_admin_scripts($hook_suffix) {
        wp_enqueue_script('jquery');
        wp_enqueue_script('woo_bonus_admin_script', WOO_BONUS_PRODUCT_PLUGIN_URL . 'includes/js/admin.js', array('wp-color-picker', 'jquery-ui-core', 'jquery-ui-dialog'), false, true);
        wp_localize_script('woo_bonus_admin_script', 'woo_bonus_script_data', array('ajaxurl' => admin_url('admin-ajax.php')));

        $woo_no_data = array(
            'no_data_found' => __('No Data Found', WOO_BONUS_PRODUCT_DOMAIN)
        );
        wp_localize_script('woo_bonus_admin_script', 'no_data_found', $woo_no_data);
        wp_enqueue_script('woo_bonus_chosen_script', WOO_BONUS_PRODUCT_PLUGIN_URL . 'includes/js/chosen.jquery.js', array('jquery'));
        wp_enqueue_script('woo_bonus_color_picker', WOO_BONUS_PRODUCT_PLUGIN_URL . 'includes/js/wp-color-picker-alpha.min.js', array('wp-color-picker'));

        wp_enqueue_style('wp-color-picker');
        wp_enqueue_style('woo_bonus_admin_styles', WOO_BONUS_PRODUCT_PLUGIN_URL . 'includes/css/admin_style.css');
        wp_enqueue_style('woo_bonus_chosen_styles', WOO_BONUS_PRODUCT_PLUGIN_URL . 'includes/css/chosen.min.css');
        wp_enqueue_style('woo_bonus_aristo_styles', WOO_BONUS_PRODUCT_PLUGIN_URL . 'includes/css/aristo.css');
    }

}

/**
 * Enqueue scripts
 * 
 * @access public
 * @since  1.0.0
 */
if (!function_exists('woo_bonus_enqueue_scripts')) {

    function woo_bonus_enqueue_scripts($hook_suffix) {
        wp_enqueue_script('jquery');
        wp_enqueue_script('woo_bonus_script', WOO_BONUS_PRODUCT_PLUGIN_URL . '/js/script.js');
        wp_localize_script('woo_bonus_script', 'woo_bonus_script_data', array('ajaxurl' => admin_url('admin-ajax.php')));
    }

}

/**
 * Show action links on the plugin screen
 *
 * @access public
 * @since  1.0.0
 * 
 * @param   mixed $links Plugin Action links
 * 
 * @return  array
 */
if (!function_exists('woo_bonus_action_links')) {
    
    function woo_bonus_action_links($links) {
        $action_links = array(
            'settings'  => '<a href="' . admin_url('admin.php?page=wc-settings&tab=woobp_settings') . '" aria-label="' . esc_attr__('View Bonus Product settings', WOO_BONUS_PRODUCT_DOMAIN) . '">' . esc_html__('Settings', WOO_BONUS_PRODUCT_DOMAIN) . '</a>',
            'docs'      => '<a href="' . esc_url('https://www.techeshta.com/docs/woo-bonus-product/') . '" target="_blank">' . esc_html__('Docs', WOO_BONUS_PRODUCT_DOMAIN) . '</a>'
        );
        return array_merge($action_links, $links);
    }
    
}

/**
 * Print Bonus product label on front-end
 * 
 * @access public
 * @since  1.0.0
 * 
 * @return label for bonus product on single product page
 */
if (!function_exists('woo_bonus_product_label')) {

    function woo_bonus_product_label() {
        $flag = false;
        
        $allow_label = false;
        global $woocommerce ,$product;
        $allow_bonus_product = get_option('woo_bonus_product_allow', true);
        $limit_to_cart_variable = get_option('woo_bonus_product_limited_to', true);
        $min_cart = get_option("woo_bonus_product_min_cart", true);
        $incart_total_item = WC()->cart->get_cart_contents_count();
        if($product->is_type( 'variable' )){
            $incart_total_amount = $woocommerce->cart->total + $product->get_variation_price( 'min' );
        }else{
            $incart_total_amount = $woocommerce->cart->total + $product->get_price();
        }
        
        if ($limit_to_cart_variable == "cartvalue") {
            $allow_label = ($allow_bonus_product == 'yes' && $incart_total_item >= $min_cart) ? true : false;
        } elseif ($limit_to_cart_variable == "cartamount") {
            $allow_label = ($allow_bonus_product == 'yes' && $incart_total_amount >= $min_cart) ? true : false;
        }
        
        $post_id = get_the_ID();
        $category_bonus_type = get_option('woo_bonus_category_type');
        $category_specific_product = get_option('woo_bonus_category_specific');

        $product_bonus_type = get_option('woo_bonus_product_type');
        $product_specific_product = get_option('woo_bonus_product_specific');

        $woo_bonus_products = $woo_bonus_product_category = array();
        $woo_bonus_settings['woo_bonus_product_allow'] = get_option('woo_bonus_product_allow');
        $woo_bonus_settings['woo_bonus_product_label'] = get_option('woo_bonus_product_label');
        $woo_bonus_settings['woobp_general_label_color'] = get_option('woobp_general_label_color');
        $woo_bonus_settings['woo_bonus_product_id'] = get_option('woo_bonus_product_id');
        $woo_bonus_settings['woo_bonus_product_category'] = get_option('woo_bonus_product_category');

        $woo_bonus_settings['woo_bonus_product_single_products'] = get_post_meta($post_id, 'woo_bonus_product_single_products', true);

        $terms = get_the_terms(get_the_ID(), 'product_cat');
        foreach ($terms as $term) {
            $product_cat_ids[] = $term->term_id;
        }
        if (is_array($woo_bonus_settings['woo_bonus_product_single_products'])) {
            $bonus_product_single_products = $woo_bonus_settings['woo_bonus_product_single_products'];
        } else {
            $bonus_product_single_products = array();
        }

        //Get bonus product category
        if (!empty($woo_bonus_settings['woo_bonus_product_category'])) {
            $woo_bonus_product_category = $woo_bonus_settings['woo_bonus_product_category'];
        }
        if (!empty($woo_bonus_settings['woo_bonus_product_id'])) {
            $woo_bonus_products = $woo_bonus_settings['woo_bonus_product_id'];
        }
        if ($woo_bonus_settings['woo_bonus_product_allow'] == "yes") {
            $flag = false;
            if (!empty($product_cat_ids)) {
                foreach ($product_cat_ids as $product_category) {
                    if (in_array($product_category, $woo_bonus_product_category)) {
                        $flag = true;
                    }
                    if ($category_bonus_type == "specific" && $post_id == $category_specific_product) {
                        $flag = false;
                    }
                }
            }
            if (!empty($woo_bonus_products) && in_array(get_the_ID(), $woo_bonus_products)) {
                $flag = true;
                if ($product_bonus_type == "specific" && $post_id == $product_specific_product) {
                    $flag = false;
                }
            }
            if (!empty($bonus_product_single_products) && in_array(get_the_ID(), $bonus_product_single_products)) {
                $flag = true;
            }
        }
        if ($flag && $allow_label) {
            $woo_bonus_label = "<span style='color: " . $woo_bonus_settings['woobp_general_label_color'] . ";margin-bottom: 15px;display: inline-block'>" . __($woo_bonus_settings['woo_bonus_product_label'], WOO_BONUS_PRODUCT_DOMAIN) . "</span>";
            echo $woo_bonus_label;
        }
    }

}

/**
 * Add product as bonus in cart
 * 
 * @access public
 * @since  1.0.0
 */
if (!function_exists('woo_bonus_add_product_to_cart')) {

    function woo_bonus_add_product_to_cart() {
        ob_start();
        if (isset($_POST['parent_id']) && $_POST['parent_id'] !== 0) {
            $parent_id = $_POST['parent_id'];
        }
        if (isset($_POST['product_id']) && $_POST['product_id'] !== 0) {
            $woo_bonus_product = $_POST['product_id'];
        }
        $user_id = get_current_user_id();
        $remove_id = get_post_meta($parent_id, "woo_bonus_product_to_cart_" . $user_id, true);
        update_post_meta($parent_id, "woo_bonus_product_to_cart_" . $user_id, $woo_bonus_product);

        //Remove if
        foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
            if ($cart_item['product_id'] == $remove_id) {
                WC()->cart->remove_cart_item($cart_item_key);
            }
        }

        //Create variation for that product
        $woo_bonus_variation = create_bonus_variation($woo_bonus_product);
        woo_bonus_add_free_product_to_cart($woo_bonus_product, $woo_bonus_variation);
        die;
    }

}

/**
 * Free bonus option tab in product add/edit
 *
 * @access public
 * @since  1.0.0
 *
 * @return void
 */
if (!function_exists('woo_bonus_create_admin_product_tab')) {
    
    function woo_bonus_create_admin_product_tab() {
        ?>
        <li class="woo_bonus_product_tab">
            <a href="#woo_bonus_product_tab">
                <?php _e('Bonus Product', WOO_BONUS_PRODUCT_DOMAIN) ?>
            </a>
        </li>
        <?php
    }
    
}

/**
 * Free bonus tab contents
 *
 * @access public
 * @since  1.0.0
 *
 * @return void
 */
if (!function_exists('woo_bonus_tab_contents')) {
    
    function woo_bonus_tab_contents() {

        $post_id = get_the_ID();
        $woo_bonus_single_enabled = get_post_meta($post_id, 'woo_bonus_product_single_enabled', true);
        $woo_bonus_products = get_post_meta($post_id, 'woo_bonus_product_single_products', true);
        ?>
        <div id="woo_bonus_product_tab" class="panel woocommerce_options_panel2">
            <div class="options_group" >
                <style>
                    #woo_bonus_product_tab .options_group {
                        padding: 10px 20px;
                    }
                    #woo_bonus_product_tab {
                        float: left;
                        width: 80%;
                    }
                    #woo_bonus_product_products_id_chosen {
                        width: 50% !important;
                    }
                </style>
                <p class="bonus-product-form-field">
                    <label for="woo_bonus_product_products_id" class="">
                        <?php _e('Select Bonus Product', WOO_BONUS_PRODUCT_DOMAIN); ?>
                    </label>
                    <?php
                    if (!is_array($woo_bonus_products)) {
                        $woo_bonus_products = array();
                    }

                    $args['post_type'] = "product";
                    $args['post__not_in'] = array($post_id);
                    $products = new WP_Query($args);
                    ?>
                </p>
                <div class="select-cover enhanced bonus-product-single-select">
                    <select name="woo_bonus_product_products_id[]" class="" id="woo_bonus_product_products_id" multiple="multiple">
                        <?php
                        if (!empty($products)) {
                            while ($products->have_posts()) : $products->the_post();
                                ?>
                                <option value="<?php echo get_the_ID(); ?>" <?php echo in_array(get_the_ID(), $woo_bonus_products) ? 'selected="selected"' : ''; ?> ><?php echo get_the_title(); ?></option>
                                <?php
                            endwhile;
                        }else {
                            ?>
                            <option value="0"><?php _e("No products", WOO_BONUS_PRODUCT_DOMAIN); ?></option>
                        <?php }
                        ?>

                    </select>

                </div>
                <div class="clearfix"></div>


            </div>
        </div>
        <?php
    }
    
}

/**
 * Save free bonus tab contents
 *
 * @access public
 * @since  1.0.0
 *
 * @param integer $post_id Current post id
 *
 * @return void
 */
if (!function_exists('woo_bonus_process_tab')) {
    
    function woo_bonus_process_tab($post_id) {

        if (!empty($_POST['woo_bonus_product_products_id'])) {
            $woo_bonus_products = array_unique($_POST['woo_bonus_product_products_id']);
            update_post_meta($post_id, 'woo_bonus_product_single_products', $woo_bonus_products);
        } else {
            delete_post_meta($post_id, 'woo_bonus_product_single_products');
        }
    }
    
}

/**
 * Return template with bonus product label
 *
 * @access public
 * @since  1.0.0
 * @static
 *
 * @param  $template template data
 * @param  $template_name template name
 * @param  $template_path template path to overwrite
 * 
 * @return label for bonus product on single product page
 */
if (!function_exists('woo_bonus_addon_plugin_template')) {

    function woo_bonus_addon_plugin_template($template, $template_name, $template_path) {
        $allow_template = false;
        global $woocommerce;
        $allow_bonus_product = get_option('woo_bonus_product_allow', true);
        $limit_to_cart_variable = get_option('woo_bonus_product_limited_to', true);
        $min_cart = get_option("woo_bonus_product_min_cart", true);
        $incart_total_item = WC()->cart->get_cart_contents_count();
        $incart_total_amount = $woocommerce->cart->total;
        if ($limit_to_cart_variable == "cartvalue") {
            $allow_template = ($allow_bonus_product == 'yes' && $incart_total_item >= $min_cart) ? true : false;
        } elseif ($limit_to_cart_variable == "cartamount") {
            $allow_template = ($allow_bonus_product == 'yes' && $incart_total_amount >= $min_cart) ? true : false;
        }

        if ($allow_template) {
            $_template = $template;
            if (!$template_path)
                $template_path = $woocommerce->template_url;

            $plugin_path = WOO_BONUS_PRODUCT_PLUGIN_DIR . '/template/woocommerce/';

            // Look within passed path within the theme - this is priority
            $template = locate_template(
                    array(
                        $template_path . $template_name,
                        $template_name
                    )
            );
            if (!$template && file_exists($plugin_path . $template_name))
                $template = $plugin_path . $template_name;
            if (!$template)
                $template = $_template;
        }
        return $template;
    }

}

/**
 * Create variation product for given item.
 *
 * @access public
 * @since  1.0.0
 * @static
 *
 * @param  integer $product_id Product to create variation of
 *
 * @return integer Product variation id
 */
if (!function_exists('create_bonus_variation')) {
    
    function create_bonus_variation($product_id) {
        //check if product variation already exists
        $product_variation = get_posts([
            'post_parent' => $product_id,
            's' => 'wbp_bonus_product',
            'post_type' => 'product_variation',
            'posts_per_page' => 1,
        ]);

        if (!empty($product_variation)) {
            //update required meta values
            update_bonus_product_meta($product_variation[0]->ID, $product_id);

            return $product_variation[0]->ID;
        }

        //if product variation doesn't exist, add one
        $admin = get_users('orderby=nicename&role=administrator&number=1');
        $variation = [
            'post_author' => $admin[0]->ID,
            'post_status' => 'publish',
            'post_name' => 'product-' . $product_id . '-variation',
            'post_parent' => $product_id,
            'post_title' => 'wbp_bonus_product',
            'post_type' => 'product_variation',
            'comment_status' => 'closed',
            'ping_status' => 'closed',
        ];

        $post_id = wp_insert_post($variation);

        //update meta values
        update_bonus_product_meta($post_id, $product_id);

        return $post_id;
    }
    
}

/**
 * Update product meta values
 *
 * @access public
 * @since  1.0.0
 * @static
 *
 * @param integer $id woo bonus product id
 * @param integer $product_id Original product id
 */
if (!function_exists('woo_bonus_update_product_meta')) {
    
    function update_bonus_product_meta($id, $product_id) {
        update_post_meta($id, '_price', 0);
        update_post_meta($id, '_regular_price', 0);
        update_post_meta($id, '_wbp_bonus_product', 1);
        update_post_meta($id, '_virtual', get_post_meta($product_id, '_virtual', true));

        update_post_meta($id, '_downloadable', get_post_meta($product_id, '_downloadable', true));
        update_post_meta($id, '_downloadable_files', get_post_meta($product_id, '_downloadable_files', true));
        update_post_meta($id, '_download_limit', get_post_meta($product_id, '_download_limit', true));
        update_post_meta($id, '_download_expiry', get_post_meta($product_id, '_download_expiry', true));
        update_post_meta($id, '_download_type', get_post_meta($product_id, '_download_type', true));
    }
    
}

/**
 * Add free bonus item to cart.
 *
 * @access public
 * @since  1.0.0
 * @static
 *
 * @param integer $parent_product_id Main product id
 * @param integer $product_id Product variation id
 *
 * @return  void
 */
if (!function_exists('woo_bonus_add_free_product_to_cart')) {
    
    function woo_bonus_add_free_product_to_cart($parent_product_id, $product_id) {
        $found = false;
        //check if product is already in cart
        if (count(WC()->cart->get_cart()) > 0) {
            foreach (WC()->cart->get_cart() as $cart_item_key => $values) {
                $_product = $values['data'];
                
                if ($_product->get_id() == $product_id) {
                    $found = true;
                }
            }

            // if product not found, add it
            if (!$found) {
                $type = __("Type", WOO_BONUS_PRODUCT_DOMAIN);
                $label = __("Bonus Product", WOO_BONUS_PRODUCT_DOMAIN);
                $woo_bonus_settings_label = get_option('woo_bonus_product_label');
                $woo_bonus_settings_color = get_option('woobp_general_label_color');
                $woo_bonus_label = "<span style='color: " . $woo_bonus_settings_color . ";'>" . __($label, WOO_BONUS_PRODUCT_DOMAIN) . "</span>";
                WC()->cart->add_to_cart($product_id, 1, $parent_product_id, [$type => $woo_bonus_label]);
            }
        }
    }
    
}

/**
 * Provide plugin settings access
 *
 * @access public
 * @since  1.0.0
 * @static
 *
 * @param array $settings woo bonus Settings
 * 
 * @return settings class of our bonus product to WordPress settings
 */
if (!function_exists('woo_bonus_plugin_settings')) {

    function woo_bonus_plugin_settings($settings) {

        $settings[] = include( WOO_BONUS_PRODUCT_PLUGIN_DIR . 'includes/class-woobp-settings.php' );

        return $settings;
    }

}

/**
 * Get Product categories
 *
 * @access public
 * @since  1.0.1
 * @static
 *
 * @return product by category array
 */
if (!function_exists('woo_bonus_get_category_products')) {

    function woo_bonus_get_category_products() {
        ob_start();
        $woo_bonus_products = get_option('woo_bonus_product_category_products', true);

        if(!is_array($woo_bonus_products)){
            $woo_bonus_products = array();
        }

        $args['post_type'] = "product";
        $args['tax_query']['relation'] = 'or';
        if (isset($_POST['categories']) && !empty($_POST['categories'])) {
            foreach ($_POST['categories'] as $category) {
                $args['tax_query'][] = array(
                    'taxonomy' => 'product_cat',
                    'field' => 'term_id',
                    'terms' => $category,
                );
            }
            $products = new WP_Query($args);
        } else {
            $products = array();
        }
        ?>
        <?php
        if (!empty($products)) {
            while ($products->have_posts()) : $products->the_post();
                ?>
                <option value="<?php echo get_the_ID(); ?>" <?php echo in_array(get_the_ID(), $woo_bonus_products) ? 'selected="selected"' : ''; ?> ><?php echo get_the_title(); ?></option>
                <?php
            endwhile;
        }else {
            ?>
            <option value="0"><?php _e("No products", WOO_BONUS_PRODUCT_DOMAIN); ?></option>
            <?php
        }

        die();
    }

}

/**
 * remove bonus product 
 *
 * @access public
 * @since  1.0.1
 * @static
 *
 * @return null
 */
if (!function_exists('woo_bonus_product_remove_cart_item')) {

    function woo_bonus_product_remove_cart_item($cart_item_key, $instance ) {
        $user_id = get_current_user_id();
        $parent_id = $instance->cart_contents[$cart_item_key]["product_id"];
        $remove_id = get_post_meta($parent_id, "woo_bonus_product_to_cart_" . $user_id, true);
        update_post_meta($parent_id,"removed_id",$remove_id);
        foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
            if ($cart_item['product_id'] == $remove_id) {
                WC()->cart->remove_cart_item($cart_item_key);
            }
        }
        delete_post_meta($parent_id, "woo_bonus_product_to_cart_" . $user_id);
    }
}

add_action( 'woocommerce_remove_cart_item', 'woo_bonus_product_remove_cart_item', 10, 2 );
